<?php
define('START_PRESS_VERSION', '1.3.2');
require_once('includes/start-press-recent-posts.php');
require_once('includes/init-theme-options.php');
require_once('includes/custom-style.php');
require_once('includes/customization.php');
require_once('wp-bootstrap-navwalker.php');
require_once('includes/set-up-assets.php');

if ( ! isset( $content_width ) ) {
  $content_width = 900;
}

function start_press_paginate() {
  global $wp_query;

  $total_pages = $wp_query->max_num_pages;

  if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
    return;
  }

  $current_page = max(1, get_query_var('paged'));
  $pages = paginate_links(array(
    'base' => str_replace($total_pages, '%#%', get_pagenum_link($total_pages)),
    'format' => '?page=%#%',
    'current' => max(1, get_query_var('paged')),
    'total' => $total_pages,
    'type' => 'array',
    'prev_next' => true,
    'prev_text' => "&laquo;" . _e('Previous', 'start-press'),
    'next_text' => _e('Next', 'start-press') . "&raquo;",
  ));
  ?>
  <nav>
    <ul class="pagination">
      <?php foreach($pages as $i => $page): ?>
        <?php if($current_page == 1 && $i == 0): ?>
          <li class='active'><?php echo $page ?></li>
        <?php else: ?>
          <?php if($current_page != 1 && $current_page == $i): ?>
            <li class='active'><?php echo $page ?></li>
          <?php else: ?>
            <li><?php echo $page ?></li>
          <?php endif; ?>
        <?php endif; ?>
      <?php endforeach; ?>
    </ul>
  </nav>
  <?php
}

function start_press_breadcrumb() {
  ?>
    <ol class="breadcrumb">
      <li>
        <a href="<?php home_url(); ?>">
          <?php _e('Home', 'start-press') ?>
        </a>
      </li>
      <?php if(is_single()): ?>
        <li>
          <?php get_category_link(the_category(', ')) ?>
        </li>
        <li class="active"><?php the_title(); ?></li>
      <?php elseif(is_page()): ?>
        <li class="active"><?php the_title(); ?></li>
      <?php elseif(is_category()):?>
        <li class="active"><?php the_title(); ?></li>
      <?php elseif(is_search()): ?>
        <li class="active"><?php the_search_query(); ?></li>
      <?php endif ?>
    </ol>
  <?php
}

function start_press_widgets_init() {
  register_sidebar( array(
    'name'          => __('Primary sidebar', 'start-press'),
    'id'            => 'primary-sidebar',
    'before_widget' => '<div>',
    'after_widget'  => '</div>',
    'before_title'  => '<h2>',
    'after_title'   => '</h2>',
  ) );

}
add_action( 'widgets_init', 'start_press_widgets_init' );

function start_press_header_banner() {
  $header_banner = get_theme_mod( 'start-press_ad_banner' );
  $header_banner_url = get_theme_mod('start-press_ad_banner_url');
  if ($header_banner) {
    ?>
      <a href="<?php echo esc_url( $header_banner_url ) ?>">
        <img src="<?php echo esc_url( $header_banner ) ?>" alt="" class='img-responsive'>
      </a>
    <?php
  }

}


add_action( 'after_setup_theme', 'start_press_theme_setup' );
function start_press_theme_setup() {
    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support( 'title-tag' );

    // Support Featured Images
    add_theme_support( 'post-thumbnails' );

    add_theme_support( 'automatic-feed-links' );

    add_theme_support( 'custom-logo' );

    load_theme_textdomain('start_press');

}

function start_press_site_logo(){
  if (has_custom_logo()) {
    the_custom_logo();
  }else{
    ?>
      <strong><?php bloginfo( 'name' ); ?></strong>
      <span><?php bloginfo( 'description' ); ?></span>
    <?php
  }
}

function start_press_add_editor_styles() {
  add_editor_style( 'custom-editor-style.css' );
}
add_action( 'admin_init', 'start_press_add_editor_styles' );


function donate_notice() {
	$class = 'notice notice-info is-dismissible';
	$message = __( 'Buy Me a Coffee To Keep My Progress', 'start-press' );
  $donate_button = '';
  ?>
    <div class="<?php echo esc_attr( $class ) ?>" style="text-align:center;">
      <p>
        <style>.bmc-button img{width: 27px !important;margin-bottom: 1px !important;box-shadow: none !important;border: none !important;vertical-align: middle !important;}.bmc-button{line-height: 60px !important;height:60px !important;text-decoration: none !important;display:inline-flex !important;color:#FFFFFF !important;background-color:#FF813F !important;border-radius: 3px !important;border: 1px solid transparent !important;padding: 0px 9px !important;font-size: 17px !important;letter-spacing:-0.08px !important;box-shadow: 0px 1px 2px rgba(190, 190, 190, 0.5) !important;-webkit-box-shadow: 0px 1px 2px 2px rgba(190, 190, 190, 0.5) !important;margin: 0 auto !important;font-family:'Lato', sans-serif !important;-webkit-box-sizing: border-box !important;box-sizing: border-box !important;-o-transition: 0.3s all linear !important;-webkit-transition: 0.3s all linear !important;-moz-transition: 0.3s all linear !important;-ms-transition: 0.3s all linear !important;transition: 0.3s all linear !important;}.bmc-button:hover, .bmc-button:active, .bmc-button:focus {-webkit-box-shadow: 0px 1px 2px 2px rgba(190, 190, 190, 0.5) !important;text-decoration: none !important;box-shadow: 0px 1px 2px 2px rgba(190, 190, 190, 0.5) !important;opacity: 0.85 !important;color:#FFFFFF !important;}</style><link href="https://fonts.googleapis.com/css?family=Lato&subset=latin,latin-ext" rel="stylesheet">
        <a class="bmc-button" target="_blank" href="https://www.buymeacoffee.com/uysim">
          <img src="https://www.buymeacoffee.com/assets/img/BMC-btn-logo.svg" alt="Buy me a coffee"><span style="margin-left:5px">
          <?php echo esc_html( $message ) ?>
        </span></a>
      </p>
    </div>
  <?php
}
add_action( 'admin_notices', 'donate_notice' );
